@@ -49,10 +49,13 @@
 #include <spot/twaalgos/canonicalize.hh>
 #include <spot/twaalgos/cobuchi.hh>
 #include <spot/twaalgos/cleanacc.hh>
+#include <spot/twaalgos/contains.hh>
+#include <spot/twaalgos/degen.hh>
 #include <spot/twaalgos/dtwasat.hh>
 #include <spot/twaalgos/dualize.hh>
 #include <spot/twaalgos/gtec/gtec.hh>
 #include <spot/twaalgos/hoa.hh>
+#include <spot/twaalgos/iscolored.hh>
 #include <spot/twaalgos/isdet.hh>
 #include <spot/twaalgos/isunamb.hh>
 #include <spot/twaalgos/isweakscc.hh>
@@ -101,6 +104,8 @@ enum {
   OPT_EXCLUSIVE_AP,
   OPT_GENERALIZED_RABIN,
   OPT_GENERALIZED_STREETT,
+  OPT_HAS_EXIST_BRANCHING,
+  OPT_HAS_UNIV_BRANCHING,
   OPT_HIGHLIGHT_NONDET,
   OPT_HIGHLIGHT_NONDET_EDGES,
   OPT_HIGHLIGHT_NONDET_STATES,
@@ -111,6 +116,7 @@ enum {
   OPT_INHERENTLY_WEAK_SCCS,
   OPT_INTERSECT,
   OPT_IS_ALTERNATING,
+  OPT_IS_COLORED,
   OPT_IS_COMPLETE,
   OPT_IS_DETERMINISTIC,
   OPT_IS_EMPTY,
@@ -181,8 +187,16 @@ static const argp_option options[] =
       "keep automata that are isomorphic to the automaton in FILENAME", 0 },
     { "isomorphic", 0, nullptr, OPTION_ALIAS | OPTION_HIDDEN, nullptr, 0 },
     { "unique", 'u', nullptr, 0,
-      "do not output the same automaton twice (same in the sense that they "\
+      "do not output the same automaton twice (same in the sense that they "
       "are isomorphic)", 0 },
+    { "has-exist-branching", OPT_HAS_EXIST_BRANCHING, nullptr, 0,
+      "keep automata that use existential branching (i.e., make "
+      "non-deterministic choices)", 0 },
+    { "has-univ-branching", OPT_HAS_UNIV_BRANCHING, nullptr, 0,
+      "keep alternating automata that use universal branching", 0 },
+    { "is-colored", OPT_IS_COLORED, nullptr, 0,
+      "keep colored automata (i.e., exactly one acceptance mark per "
+      "transition or state)", 0 },
     { "is-complete", OPT_IS_COMPLETE, nullptr, 0,
       "keep complete automata", 0 },
     { "is-deterministic", OPT_IS_DETERMINISTIC, nullptr, 0,
@@ -303,8 +317,7 @@ static const argp_option options[] =
     { "cleanup-acceptance", OPT_CLEAN_ACC, nullptr, 0,
       "remove unused acceptance sets from the automaton", 0 },
     { "complement", OPT_COMPLEMENT, nullptr, 0,
-      "complement each automaton (currently support only deterministic "
-      "automata)", 0 },
+      "complement each automaton (currently via determinization)", 0 },
     { "complement-acceptance", OPT_COMPLEMENT_ACC, nullptr, 0,
       "complement the acceptance condition (without touching the automaton)",
       0 },
@@ -554,7 +567,10 @@ static struct opt_t
 }* opt;
 
 static bool opt_merge = false;
+static bool opt_has_univ_branching = false;
+static bool opt_has_exist_branching = false;
 static bool opt_is_alternating = false;
+static bool opt_is_colored = false;
 static bool opt_is_complete = false;
 static bool opt_is_deterministic = false;
 static bool opt_is_semi_deterministic = false;
@@ -599,7 +615,7 @@ static bool opt_complement = false;
 static bool opt_complement_acc = false;
 static char* opt_decompose_scc = nullptr;
 static bool opt_dualize = false;
-static spot::acc_cond::mark_t opt_mask_acc = 0U;
+static spot::acc_cond::mark_t opt_mask_acc = {};
 static std::vector<bool> opt_keep_states = {};
 static unsigned int opt_keep_states_initial = 0;
 static bool opt_simpl_acc = false;
@@ -628,6 +644,42 @@ ensure_deterministic(const spot::twa_graph_ptr& aut, bool nonalt = false)
   return p.run(aut);
 }
 
+static spot::twa_graph_ptr ensure_tba(spot::twa_graph_ptr aut)
+{
+  spot::postprocessor p;
+  p.set_type(spot::postprocessor::TGBA);
+  p.set_pref(spot::postprocessor::Any);
+  p.set_level(spot::postprocessor::Low);
+  return spot::degeneralize_tba(p.run(aut));
+
+}
+
+static spot::twa_graph_ptr
+product(spot::twa_graph_ptr left, spot::twa_graph_ptr right)
+{
+  if ((type == spot::postprocessor::BA)
+      && (left->num_sets() + right->num_sets() >
+          spot::acc_cond::mark_t::max_accsets()))
+    {
+      left = ensure_tba(left);
+      right = ensure_tba(right);
+    }
+  return spot::product(left, right);
+}
+
+static spot::twa_graph_ptr
+product_or(spot::twa_graph_ptr left, spot::twa_graph_ptr right)
+{
+  if ((type == spot::postprocessor::BA)
+      && (left->num_sets() + right->num_sets() >
+          spot::acc_cond::mark_t::max_accsets()))
+    {
+      left = ensure_tba(left);
+      right = ensure_tba(right);
+    }
+  return spot::product_or(left, right);
+}
+
 static int
 parse_opt(int key, char* arg, struct argp_state*)
 {
@@ -641,7 +693,7 @@ parse_opt(int key, char* arg, struct argp_state*)
       jobs.emplace_back(arg, true);
       break;
     case 'n':
-      opt_max_count = to_pos_int(arg);
+      opt_max_count = to_pos_int(arg, "-n/--max-count");
       break;
     case 'u':
       opt->uniq =
@@ -786,17 +838,25 @@ parse_opt(int key, char* arg, struct argp_state*)
         opt_gsa = GSA_UNIQUE_FIN;
       opt_gra = GRA_NO;
       break;
+    case OPT_HAS_EXIST_BRANCHING:
+      opt_has_exist_branching = true;
+      break;
+    case OPT_HAS_UNIV_BRANCHING:
+      opt_has_univ_branching = true;
+      break;
     case OPT_HIGHLIGHT_NONDET:
       {
-        int v = arg ? to_pos_int(arg) : 1;
+        int v = arg ? to_pos_int(arg, "--highlight-nondet") : 1;
         opt_highlight_nondet_edges = opt_highlight_nondet_states = v;
         break;
       }
     case OPT_HIGHLIGHT_NONDET_STATES:
-      opt_highlight_nondet_states = arg ? to_pos_int(arg) : 1;
+      opt_highlight_nondet_states =
+        arg ? to_pos_int(arg, "--highlight-nondet-states") : 1;
       break;
     case OPT_HIGHLIGHT_NONDET_EDGES:
-      opt_highlight_nondet_edges = arg ? to_pos_int(arg) : 1;
+      opt_highlight_nondet_edges =
+        arg ? to_pos_int(arg, "--highlight-nondet-edges") : 1;
       break;
     case OPT_HIGHLIGHT_WORD:
       {
@@ -862,6 +922,9 @@ parse_opt(int key, char* arg, struct argp_state*)
     case OPT_IS_ALTERNATING:
       opt_is_alternating = true;
       break;
+    case OPT_IS_COLORED:
+      opt_is_colored = true;
+      break;
     case OPT_IS_COMPLETE:
       opt_is_complete = true;
       break;
@@ -919,8 +982,8 @@ parse_opt(int key, char* arg, struct argp_state*)
             if (res < 0)
               error(2, 0, "acceptance sets should be non-negative:"
                     " --mask-acc=%ld", res);
-            if (static_cast<unsigned long>(res)
-                > sizeof(spot::acc_cond::mark_t::value_t))
+            if (static_cast<unsigned long>(res) >=
+                spot::acc_cond::mark_t::max_accsets())
               error(2, 0, "this implementation does not support that many"
                     " acceptance sets: --mask-acc=%ld", res);
             opt_mask_acc.set(res);
@@ -937,8 +1000,8 @@ parse_opt(int key, char* arg, struct argp_state*)
         if (!opt->product_and)
           opt->product_and = std::move(a);
         else
-          opt->product_and = spot::product(std::move(opt->product_and),
-                                           std::move(a));
+          opt->product_and = ::product(std::move(opt->product_and),
+                                       std::move(a));
       }
       break;
     case OPT_PRODUCT_OR:
@@ -947,8 +1010,8 @@ parse_opt(int key, char* arg, struct argp_state*)
         if (!opt->product_or)
           opt->product_or = std::move(a);
         else
-          opt->product_or = spot::product_or(std::move(opt->product_or),
-                                             std::move(a));
+          opt->product_or = ::product_or(std::move(opt->product_or),
+                                         std::move(a));
       }
       break;
     case OPT_RANDOMIZE:
@@ -1012,7 +1075,7 @@ parse_opt(int key, char* arg, struct argp_state*)
       opt_sccs = parse_range(arg, 0, std::numeric_limits<int>::max());
       break;
     case OPT_SEED:
-      opt_seed = to_int(arg);
+      opt_seed = to_int(arg, "--seed");
       break;
     case OPT_SEP_SETS:
       opt_sep_sets = true;
@@ -1263,6 +1326,8 @@ namespace
         }
       if (matched && opt_is_alternating)
         matched &= !aut->is_existential();
+      if (matched && opt_is_colored)
+        matched &= is_colored(aut);
       if (matched && opt_is_complete)
         matched &= is_complete(aut);
 
@@ -1313,6 +1378,10 @@ namespace
         }
       if (opt_nondet_states_set)
         matched &= opt_nondet_states.contains(spot::count_nondet_states(aut));
+      if (opt_has_univ_branching)
+        matched &= !aut->is_existential();
+      if (opt_has_exist_branching)
+        matched &= !is_universal(aut);
       if (opt_is_deterministic)
         {
           matched &= is_deterministic(aut);
@@ -1342,8 +1411,7 @@ namespace
         matched &= !aut->intersects(opt->included_in);
       if (opt->equivalent_pos)
         matched &= !aut->intersects(opt->equivalent_neg)
-          && (!dualize(ensure_deterministic(aut, true))->
-              intersects(opt->equivalent_pos));
+          && spot::contains(aut, opt->equivalent_pos);
 
       if (matched && !opt->acc_words.empty())
         for (auto& word_aut: opt->acc_words)
@@ -1399,9 +1467,9 @@ namespace
         aut->purge_unreachable_states();
 
       if (opt->product_and)
-        aut = spot::product(std::move(aut), opt->product_and);
+        aut = ::product(std::move(aut), opt->product_and);
       if (opt->product_or)
-        aut = spot::product_or(std::move(aut), opt->product_or);
+        aut = ::product_or(std::move(aut), opt->product_or);
 
       if (opt->sum_or)
         aut = spot::sum(std::move(aut), opt->sum_or);
@@ -1423,7 +1491,10 @@ namespace
         }
 
       if (opt_complement)
-        aut = spot::dualize(ensure_deterministic(aut));
+        {
+          aut = spot::dualize(ensure_deterministic(aut));
+          aut->merge_edges();
+        }
 
       if (opt_dualize)
         aut = spot::dualize(aut);
@@ -1494,13 +1565,10 @@ namespace
 int
 main(int argc, char** argv)
 {
-  setup(argv);
+  return protected_main(argv, [&] {
+      const argp ap = { options, parse_opt, "[FILENAME[/COL]...]",
+                        argp_program_doc, children, nullptr, nullptr };
 
-  const argp ap = { options, parse_opt, "[FILENAME[/COL]...]",
-                    argp_program_doc, children, nullptr, nullptr };
-
-  try
-    {
       // This will ensure that all objects stored in this struct are
       // destroyed before global variables.
       opt_t o;
@@ -1542,19 +1610,11 @@ main(int argc, char** argv)
 
       // Diagnose unused -x options
       extra_options.report_unused_options();
-    }
-  catch (const std::runtime_error& e)
-    {
-      error(2, 0, "%s", e.what());
-    }
-  catch (const std::invalid_argument& e)
-    {
-      error(2, 0, "%s", e.what());
-    }
 
-  if (automaton_format == Count)
-    std::cout << match_count << std::endl;
+      if (automaton_format == Count)
+        std::cout << match_count << std::endl;
 
-  check_cout();
-  return !match_count;
+      check_cout();
+      return match_count ? 0 : 1;
+    });
 }
