@@ -1,9 +1,9 @@
 // -*- coding: utf-8 -*-
-// Copyright (C) 2009, 2012-2017 Laboratoire de Recherche et
+// Copyright (C) 2009, 2012-2018 Laboratoire de Recherche et
 // Développement de l'Epita (LRDE).
-// Copyright (C) 2003, 2004, 2005, 2006 Laboratoire d'Informatique de
-// Paris 6 (LIP6), département Systèmes Répartis Coopératifs (SRC),
-// Université Pierre et Marie Curie.
+// Copyright (C) 2003-2006 Laboratoire d'Informatique de Paris 6
+// (LIP6), département Systèmes Répartis Coopératifs (SRC), Université
+// Pierre et Marie Curie.
 //
 // This file is part of Spot, a model checking library.
 //
@@ -20,6 +20,7 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+#include "config.h"
 #include <ostream>
 #include <sstream>
 #include <cassert>
@@ -54,6 +55,19 @@ namespace spot
       {
       }
 
+      anon_free_list(const anon_free_list& other) noexcept
+        : free_list(other), priv_(other.priv_)
+      {
+      }
+
+      spot::bdd_dict_priv::anon_free_list&
+      operator=(const anon_free_list& other) noexcept
+      {
+        spot::free_list::operator=(other);
+        priv_ = other.priv_;
+        return *this;
+      }
+
       virtual int
       extend(int n) override
       {
