@@ -1,6 +1,6 @@
 // -*- coding: utf-8 -*-
-// Copyright (C) 2009, 2011, 2012, 2014, 2015, 2016, 2017 Laboratoire
-// de Recherche et Développement de l'Epita (LRDE).
+// Copyright (C) 2009, 2011-2012, 2014-2018 Laboratoire de Recherche
+// et Développement de l'Epita (LRDE).
 // Copyright (C) 2003, 2004, 2006 Laboratoire d'Informatique de
 // Paris 6 (LIP6), département Systèmes Répartis Coopératifs (SRC),
 // Université Pierre et Marie Curie.
@@ -20,6 +20,7 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+#include "config.h"
 #include <spot/twa/twaproduct.hh>
 #include <string>
 #include <cassert>
@@ -45,7 +46,7 @@ namespace spot
       return;
     fixed_size_pool* p = pool_;
     this->~state_product();
-    p->deallocate(this);
+    p->deallocate(const_cast<state_product*>(this));
   }
 
   int
