@@ -1,5 +1,5 @@
 // -*- coding: utf-8 -*-
-// Copyright (C) 2009, 2011-2017 Laboratoire de Recherche et
+// Copyright (C) 2009, 2011-2018 Laboratoire de Recherche et
 // Développement de l'Epita (LRDE).
 // Copyright (C) 2004, 2005 Laboratoire d'Informatique de Paris 6 (LIP6),
 // département Systèmes Répartis Coopératifs (SRC), Université Pierre
@@ -20,6 +20,7 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+#include "config.h"
 #include <sstream>
 #include <memory>
 #include <spot/twaalgos/emptiness.hh>
@@ -365,7 +366,7 @@ namespace spot
 
     // Start from the end of the original cycle, and rewind until all
     // acceptance sets have been seen.
-    acc_cond::mark_t seen_acc = 0U;
+    acc_cond::mark_t seen_acc = {};
     twa_run::steps::const_iterator seg = cycle.end();
     do
       {
@@ -378,7 +379,7 @@ namespace spot
 
     // Now go forward and ends the segment as soon as we have seen all
     // acceptance sets, cloning it in our result along the way.
-    seen_acc = 0U;
+    seen_acc = {};
     do
       {
         assert(seg != cycle.end());
@@ -515,7 +516,7 @@ namespace spot
     int serial = 1;
     const twa_run::steps* l;
     std::string in;
-    acc_cond::mark_t all_acc = 0U;
+    acc_cond::mark_t all_acc = {};
     bool all_acc_seen = false;
     state_map<std::set<int>> seen;
 
@@ -780,7 +781,7 @@ namespace spot
     unsigned src;
     unsigned dst;
     const twa_run::steps* l;
-    acc_cond::mark_t seen_acc = 0U;
+    acc_cond::mark_t seen_acc = {};
 
     state_map<unsigned> seen;
 
