@@ -1,5 +1,5 @@
 // -*- coding: utf-8 -*-
-// Copyright (C) 2011, 2013-2018  Laboratoire de recherche et
+// Copyright (C) 2011, 2013-2019  Laboratoire de recherche et
 // développement de l'Epita (LRDE).
 // Copyright (C) 2004, 2005  Laboratoire d'Informatique de Paris 6 (LIP6),
 // département Systèmes Répartis Coopératifs (SRC), Université Pierre
@@ -588,14 +588,18 @@ namespace spot
   emptiness_check_ptr
   explicit_magic_search(const const_twa_ptr& a, option_map o)
   {
-    return std::make_shared<magic_search_<explicit_magic_search_heap>>(a, 0, o);
+    return
+      SPOT_make_shared_enabled__(magic_search_<explicit_magic_search_heap>,
+                                 a, 0, o);
   }
 
   emptiness_check_ptr
   bit_state_hashing_magic_search(const const_twa_ptr& a,
                                  size_t size, option_map o)
   {
-    return std::make_shared<magic_search_<bsh_magic_search_heap>>(a, size, o);
+    return
+      SPOT_make_shared_enabled__(magic_search_<bsh_magic_search_heap>,
+                                 a, size, o);
   }
 
   emptiness_check_ptr
