@@ -1,6 +1,6 @@
 // -*- coding: utf-8 -*-
-// Copyright (C) 2012, 2014, 2015, 2017 Laboratoire de Recherche et
-// Développement de l'Epita (LRDE).
+// Copyright (C) 2012, 2014-2015, 2017-2018 Laboratoire de Recherche
+// et Développement de l'Epita (LRDE).
 //
 // This file is part of Spot, a model checking library.
 //
@@ -17,8 +17,8 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+#include "config.h"
 #include <spot/twaalgos/stripacc.hh>
-#include <spot/twaalgos/reachiter.hh>
 
 namespace spot
 {
@@ -27,7 +27,7 @@ namespace spot
     unsigned n = a->num_states();
     for (unsigned s = 0; s < n; ++s)
       for (auto& t: a->out(s))
-        t.acc = 0U;
+        t.acc = {};
     a->set_generalized_buchi(0);
     a->release_named_properties();
     a->prop_weak(true);
