@@ -17,6 +17,7 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+#include "config.h"
 #include <spot/twaalgos/stutter.hh>
 #include <spot/twa/twa.hh>
 #include <spot/misc/hash.hh>
@@ -31,8 +32,6 @@
 #include <spot/twaalgos/remfin.hh>
 #include <spot/twaalgos/postproc.hh>
 #include <spot/twaalgos/sccinfo.hh>
-#include <spot/twaalgos/postproc.hh>
-#include <spot/twaalgos/dualize.hh>
 #include <spot/twa/twaproduct.hh>
 #include <spot/twa/bddprint.hh>
 #include <deque>
@@ -78,7 +77,7 @@ namespace spot
       virtual
       state_tgbasl* clone() const override
       {
-        return new state_tgbasl(*this);
+        return new state_tgbasl(s_, cond_);
       }
 
       const state*
@@ -180,7 +179,7 @@ namespace spot
       acc() const override
       {
         if (loop_)
-          return 0U;
+          return {};
         return it_->acc();
       }
 
@@ -328,7 +327,7 @@ namespace spot
           }
 
         if (self_loop_needed && s.second != bddfalse)
-          res->new_edge(src, src, s.second, 0U);
+          res->new_edge(src, src, s.second, {});
       }
     res->merge_edges();
     return res;
@@ -380,10 +379,10 @@ namespace spot
                 unsigned tmp = p.first->second; // intermediate state
                 unsigned i = a->new_edge(src, tmp, one, acc);
                 assert(i > num_edges);
-                i = a->new_edge(tmp, tmp, one, 0U);
+                i = a->new_edge(tmp, tmp, one, {});
                 assert(i > num_edges);
                 // No acceptance here to preserve the state-based property.
-                i = a->new_edge(tmp, dst, one, 0U);
+                i = a->new_edge(tmp, dst, one, {});
                 assert(i > num_edges);
                 (void)i;
               }
