@@ -17,7 +17,7 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-
+#include "config.h"
 #include <iostream>
 #include <spot/graph/ngraph.hh>
 #include <spot/twa/twa.hh>
@@ -345,6 +345,19 @@ public:
   {
   }
 
+  my_state() noexcept
+  {
+  }
+
+  my_state(const my_state&) noexcept
+  {
+  }
+
+  my_state& operator=(const my_state&) noexcept
+  {
+    return *this;
+  }
+
   int compare(const spot::state* other) const override
   {
     auto o = spot::down_cast<const my_state*>(other);
