@@ -1,6 +1,6 @@
 // -*- coding: utf-8 -*-
-// Copyright (C) 2011, 2012, 2013, 2014, 2015, 2016, 2017 Laboratoire de
-// Recherche et Developpement de l'Epita (LRDE)
+// Copyright (C) 2011-2018 Laboratoire de Recherche et Developpement
+// de l'Epita (LRDE)
 //
 // This file is part of Spot, a model checking library.
 //
@@ -17,6 +17,7 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+#include "config.h"
 #include <spot/ltsmin/ltsmin.hh>
 #include <spot/twaalgos/dot.hh>
 #include <spot/tl/defaultenv.hh>
@@ -221,7 +222,7 @@ checked_main(int argc, char **argv)
           model = spot::ltsmin_model::load(argv[1]).kripke(&ap, dict, deadf,
                                                            compress_states);
         }
-      catch (std::runtime_error& e)
+      catch (const std::runtime_error& e)
         {
           std::cerr << e.what() << '\n';
         }
